@@ -115,27 +115,46 @@ class PickingRequest(object):
         if type(params["move_lines"]) != list:
             params["move_lines"] = [params["move_lines"]]
         API_LOGS.logger.info(params)
-        for move in params["move_lines"]:
-            move["location_id"] = params["location_id"]
-            move["location_dest_id"] = params["location_dest_id"]
-            move["company_id"] = params["company_id"]
-            move["date"] = params["date"]
-            move["date_expected"] = params["date"]
-            move["serial_number"] = [move["serial_number"]]
-            move["name"] = params["name"]
-            move["product_uom"] = 1
-            move["product_uom_qty"] = 1
-            move["procure_method"] = "make_to_stock"
-            move["product_id"] = int(move["product_id"])
+        product_id = []
+        for i in params["move_lines"]:
+            product_id.append(i["product_id"])
+
+        product_id = list(set(product_id))
+
+        move_lines = []
+        for i in product_id:
+            serial = []
+            for move in params["move_lines"]:
+                if move["product_id"] == i:
+                    serial.append(move["serial_number"])
+            move_lines.append({
+                'company_id': params["company_id"],
+                'product_uom': 1,
+                'location_id': params["location_id"],
+                'procure_method': 'make_to_stock',
+                'serial_number': serial,
+                'date_expected': params["date"],
+                'date': params["date"],
+                'name': params["name"],
+                'location_dest_id': params["location_dest_id"],
+                'product_id': int(i),
+                'product_uom_qty': len(serial)
+                })
 
-        params.pop("date")
-        params.pop("name")
         data = {
             "jsonrpc": "2.0",
             "params": {
-                "vals": params
+                "vals": {
+                    "move_type": "direct",
+                    "location_id": params["location_id"],
+                    "location_dest_id": params["location_dest_id"],
+                    "picking_type_id": 1,
+                    "company_id": 1,
+                    "move_lines": move_lines
+                    }
                 }
             }
+        API_LOGS.logger.info(data)
         response = ODOO_CLIENT.post(
             '/stocks/picking/requests', json=data
             )
